from django.contrib import admin

# Register your models here.
from bigsansar.contrib.sites.forms import create_domainform
from bigsansar.contrib.sites.models import domains, pages


class domainadmin(admin.ModelAdmin):
    form = create_domainform
    list_display = ['domain', 'publish_date', 'visitor']


class pageadmin(admin.ModelAdmin):
    pass


admin.site.register(domains, domainadmin)
admin.site.register(pages, pageadmin)